✨ Streamlit Render &nbsp; [![GitHub][github_badge]][github_link] [![PyPI][pypi_badge]][pypi_link]
=====================

create and be able to use 3d models on streamlit

---
[github_badge]: https://badgen.net/badge/icon/GitHub?icon=github&color=black&label
[github_link]: https://github.com/baolongdev/streamlit_render

[pypi_badge]: https://badgen.net/pypi/v/streamlit-render?icon=pypi&color=black&label
[pypi_link]: https://pypi.org/project/streamlit-render


Getting started
---------------

### 1. Introduction
Streamlit Render is a component that gives you the tools to create and render 3d models

#### Installation
```sh
pip install streamlit-render==0.1.*
```
**Caution**: It is recommended to pin the version to `0.1.*`. Future versions might introduce breaking API changes.